# Utils

Utilities, complementing the Python Standard Library

[https://pypi.org/project/utils-nuuuwan](https://pypi.org/project/utils-nuuuwan)

## Setup & Install

```
pip install utils-nuuuwan
```

## Implementation Details

This library is a aggregation of the following libraries

* [utils_base](https://pypi.org/project/utils_base-nuuuwan/)
* [utils_git](https://pypi.org/project/utils_git-nuuuwan/)
* [utils_twitter](https://pypi.org/project/utils_twitter-nuuuwan/)
* [utils_www](https://pypi.org/project/utils_www-nuuuwan/)

## Recent Version History

### 2.0.6
* utils_base-nuuuwan==1.0.4

